package Bundle::Locale::CLDR::Polynesia;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Polynesia

=head1 CONTENTS

Locale::CLDR::Locales::Fr 0.46.0

Locale::CLDR::Locales::To 0.46.0

Locale::CLDR::Locales::Fr::Latn 0.46.0

Locale::CLDR::Locales::To::Latn 0.46.0

Locale::CLDR::Locales::En::Latn::As 0.46.0

Locale::CLDR::Locales::En::Latn::Ck 0.46.0

Locale::CLDR::Locales::En::Latn::Nu 0.46.0

Locale::CLDR::Locales::En::Latn::Pn 0.46.0

Locale::CLDR::Locales::En::Latn::Tk 0.46.0

Locale::CLDR::Locales::En::Latn::To 0.46.0

Locale::CLDR::Locales::En::Latn::Tv 0.46.0

Locale::CLDR::Locales::En::Latn::Ws 0.46.0

Locale::CLDR::Locales::Fr::Latn::Pf 0.46.0

Locale::CLDR::Locales::Fr::Latn::Wf 0.46.0

Locale::CLDR::Locales::To::Latn::To 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0


=cut

1;

